:mod:`cybox.objects.win_filemapping_object` module
==================================================

.. automodule:: cybox.objects.win_filemapping_object
    :members:
    :undoc-members:
    :show-inheritance:
